@@ -50,41 +50,41 @@ downloads, installation and source code.
 
 __Conventions__  = 'CF-1.5'
 __author__       = 'David Hassell'
-__date__         = '23 June 2015'
-__version__      = '1.0.3'
+__date__         = '28 October 2015'
+__version__      = '1.1'
 
+from distutils.version import StrictVersion
 import imp
 import platform
 
 # Check the version of python
-if not '2.6.0' <= platform.python_version() < '3.0.0':
+if not (StrictVersion('2.6.0')
+        <= StrictVersion(platform.python_version())
+        < StrictVersion('3.0.0')):
     raise ValueError(
         "Bad python version: cf requires 2.6 <= python < 3.0. Got %s" %
         platform.python_version())
 
 # Check the version of numpy
 import numpy
-if numpy.__version__ < '1.7':
+if StrictVersion(numpy.__version__) < StrictVersion('1.7'):
     raise ImportError(
         "Bad numpy version: cf %s requires numpy >= 1.7. Got %s" %
         (__version__, numpy.__version__))
 
 # Check the version of netCDF4
 import netCDF4
-if netCDF4.__version__ < '0.9.7':
+if StrictVersion(netCDF4.__version__) < StrictVersion('0.9.7'):
     raise ImportError(
         "Bad netCDF4 version: cf %s requires netCDF4 >= 0.9.7. Got %s" %
         (__version__, netCDF4.__version__))
 
-# Ready for regridding in v1.1:
-_found_ESMF = False
-#try:
-#    imp.find_module('ESMF')
-#except ImportError:
-#    _found_ESMF = False
-#else:
-#    _found_ESMF = True
-##--- End: for
+try:
+    imp.find_module('ESMF')
+except ImportError:
+    _found_ESMF = False
+else:
+    _found_ESMF = True
 
 from .variable             import Variable
 from .coordinate           import Coordinate, DimensionCoordinate, AuxiliaryCoordinate
@@ -92,11 +92,10 @@ from .coordinatebounds     import CoordinateBounds
 from .coordinatereference  import CoordinateReference
 from .cellmeasure          import CellMeasure
 from .domain               import Domain
-from .field                import Field
-from .fieldlist            import FieldList
+from .field                import Field, FieldList
 from .read                 import read
 from .write                import write
-from .utils                import List, Dict
+from .utils                import Dict #List, Dict
 from .units                import Units
 from .cfdatetime           import Datetime, dt
 from .timeduration         import TimeDuration, Y, M, D, h, m, s
@@ -109,10 +108,7 @@ from .query                import (Query, lt, le, gt, ge, eq, ne, contain,
                                    cellwi, cellwo, djf, mam, jja, son, seasons)
 from .flags                import Flags
 from .cellmethods          import CellMethods
-from .ancillaryvariables   import AncillaryVariables
 from .constants            import *
 from .functions            import *
 
-# Ready for regridding in v1.1
-#from .regrid               import Regrid as _Regrid
 
