@@ -6,8 +6,8 @@ from os   import SEEK_SET
 from os.path import expandvars as os_path_expandvars
 from os.path import expanduser as os_path_expanduser
 
-from .field     import Field
-from .fieldlist import FieldList
+from .field     import Field, FieldList
+#from .fieldlist import FieldList
 from .functions import flat
 from .aggregate import aggregate as cf_aggregate
 
@@ -17,8 +17,8 @@ from .um.read     import read as um_read
 from .um.read     import is_um_file
 
 def read(files, verbose=False, ignore_read_error=False, aggregate=True,
-         umversion=4.5, squeeze=False, unsqueeze=False, fmt=None,
-         select=None, select_options={}):
+         umversion=4.5, nfields=None, squeeze=False, unsqueeze=False, fmt=None,
+         select=None, select_options={}, top_level=None):
     '''Read fields from files into `cf.Field` objects.
 
 A file may be on disk or on a OPeNDAP server.
@@ -86,17 +86,18 @@ Any amount of any combination of CF-netCDF, CFA-netCDF and Met Office
         If True then print information to stdout.
     
     umversion : int or float, optional
-        For PP format files only, the Unified Model (UM) version to be
-        used when decoding the PP header. Valid versions are, for
-        example, ``4.2``, ``'6.6.3'`` and ``'8.2'``.  The default
-        version is ``4.5``. The version is ignored if it can be
-        inferred from the PP headers, which will generally be the case
-        for files created at versions 5.3 and later. Note that the PP
-        header can not encode tertiary version elements (such as the
-        ``3`` in ``'6.6.3'``), so it may be necessary to provide a UM
-        version in such cases.
+        Met Office (UK) PP files and Met Office (UK) fields files
+        only, the Unified Model (UM) version to be used when decoding
+        the header. Valid versions are, for example, ``402``,
+        ``'606.3'`` and ``'1001'``.  The default version is
+        ``405``. The version is ignored if it can be inferred from the
+        headers (which is generally true for PP files created at
+        version 5.3 and later and for all fields files). Note that
+        the PP header can not encode tertiary version elements (such
+        as the ``3`` in ``606.3``), so it may be necessary to provide
+        a UM version in such cases.
 
-        Ignored for any non-PP input files.
+        Ignored for any other type of input files.
 
     ignore_read_error : bool, optional
         If True then ignore any file which raises an IOError whilst
@@ -132,11 +133,37 @@ Any amount of any combination of CF-netCDF, CFA-netCDF and Met Office
         satisfy ``f.match(select, **select_options) == True`` are
         returned. See `cf.Field.match` for details.
 
+    top_level : (sequence of) str, optional
+        Promote field components to independent top-level fields. The
+        *top_level* parameter may be or, or a sequence, of:
+
+          ===============  ===========================================
+          *top_level*      Extra top-level fields
+          ===============  ===========================================
+          ``'reference'``  Fields in coordinate reference objects
+          ``'ancillary'``  Ancillary data fields
+          ``'field'``      Fields in coordinate references and
+                           ancillary data fields
+          ``'auxiliary'``  Auxiliary coordinate objects
+          ``'measure'``    Cell measure objects
+          ``'all'``        All of the above
+          ===============  ===========================================
+
+            *Example:*
+              To promote fields in coordinate reference objects:
+              ``top_level='reference'`` or ``top_level=['reference']``.
+
+            *Example:*
+              To promote ancillary data fields and cell measure
+              objects: ``top_level=['ancillary', 'measure']``.
+
+        .. versionadded:: 1.0.4
+
 :Returns:
     
-    out : cf.FieldList
-        A list of fields.
-
+    out : cf.FieldList or cf.Field
+        A list of fields, or if there is only one field, the
+        individual field.
 
 :Examples:
 
@@ -184,11 +211,24 @@ Any amount of any combination of CF-netCDF, CFA-netCDF and Met Office
 
     aggregate_options['copy'] = False
     
+    # Parse umversion
     if umversion is not None:
-        # Parse umversion
         umversion = str(umversion)
         umversion = umversion.replace('.', '0', 1)
 
+    # ----------------------------------------------------------------
+    # Parse top_level
+    # ----------------------------------------------------------------
+    promote = top_level
+    if promote is None:
+        promote = ()
+    elif isinstance(promote, basestring):
+        promote = (promote,)
+
+#    if 'all' in promote:
+#        promote = set(('field', 'coordinate', 'measure'))
+        
+
     # Count the number of fields (in all files) and the number of
     # files
     field_counter = -1
@@ -223,7 +263,8 @@ Any amount of any combination of CF-netCDF, CFA-netCDF and Met Office
                                   aggregate=aggregate,
                                   aggregate_options=aggregate_options,
                                   umversion=umversion,
-                                  selected_fmt=fmt)
+                                  selected_fmt=fmt,
+                                  promote=promote)
             
             # --------------------------------------------------------
             # Select matching fields
@@ -252,9 +293,9 @@ Any amount of any combination of CF-netCDF, CFA-netCDF and Met Office
 
     # Print some informative messages
     if verbose:
-        print("Read %d field%s from %d file%s" % 
-              (field_counter, ('s' if field_counter!=1 else ''),
-               file_counter , ('s' if file_counter !=1 else '')))
+        print("Read {0} field{1} from {2} file{3}".format( 
+              (field_counter, _plural(field_counter),
+               file_counter , _plural(file_counter))))
     #--- End: if
     
     # ----------------------------------------------------------------
@@ -267,10 +308,10 @@ Any amount of any combination of CF-netCDF, CFA-netCDF and Met Office
         field_list = cf_aggregate(field_list, **aggregate_options)
         
         if verbose:
-            nfields = len(field_list)
-            print('%d input field%s aggregated into %d field%s' %
-                  (org_len, ('' if org_len==1 else 's'), 
-                   nfields, ('' if nfields==1 else 's')))
+            n = len(field_list)
+            print('{0} input field{1} aggregated into {2} field{3}'.format(
+                  (org_len, _plural(org_len), 
+                   n, _plural(n))))
     #--- End: if
 
     # ----------------------------------------------------------------
@@ -299,16 +340,32 @@ Any amount of any combination of CF-netCDF, CFA-netCDF and Met Office
     elif unsqueeze:
         field_list.unsqueeze(i=True)
 
+    if nfields is not None and len(field_list) != nfields:
+        raise ValueError(
+            "Error whilst reading file{0}: {1} field{2} requested but {3} found".format(
+                _plural(file_counter),
+                nfields,
+                _plural(nfields),
+                len(field_list)))
+
+    if len(field_list) == 1:
+        # Return a field instead of a field list
+        field_list = field_list[0]
+
     return field_list
 #--- End: def
 
+def _plural(n):
+    return 's' if n !=1 else ''
+
 def _read_a_file(filename,
                  aggregate=True,
                  aggregate_options={},
                  ignore_read_error=False,
                  verbose=False,
                  umversion=None,
-                 selected_fmt=None):
+                 selected_fmt=None,
+                 promote=()):
     '''
 
 Read the contents of a single file into a field list.
@@ -361,7 +418,8 @@ Read the contents of a single file into a field list.
     # Still here? Read the file into fields.
     # ----------------------------------------------------------------
     if ftype == 'netCDF' and (selected_fmt in (None, 'NETCDF', 'CFA')):
-        fields = netcdf_read(filename, fmt=selected_fmt, verbose=verbose)
+        fields = netcdf_read(filename, fmt=selected_fmt, promote=promote,
+                             verbose=verbose)
         
     elif ftype == 'UM' and (selected_fmt in (None, 'PP', 'FF')):
         fields = um_read(filename, um_version=umversion, verbose=verbose,
@@ -375,7 +433,7 @@ Read the contents of a single file into a field list.
                 aggregate_options['relaxed_units'] = True
         #--- End: if
 
-    # Developers: Add more file formats here ...
+    # Add more file formats here ...
 
     else:
         fields = FieldList()
