@@ -28,7 +28,26 @@ class read_writeTest(unittest.TestCase):
         f = cf.read(self.filename, select='eastward_wind')
         g = cf.read(self.filename)
         self.assertTrue(f.equals(g, traceback=True),
-                        'Bad read with select keyqword')
+                        'Bad read with select keyword')
+    #--- End: def
+
+    def test_read_top_level(self):
+        # Test top_level keyword of cf.read
+        filename = self.filename
+        self.assertTrue(len(cf.read(filename)) == 1)
+        self.assertTrue(len(cf.read(filename, top_level=['dimension'])) == 6)
+        self.assertTrue(len(cf.read(filename, top_level=['auxiliary'])) == 11)
+        self.assertTrue(len(cf.read(filename, top_level='measure')) == 4)
+        self.assertTrue(len(cf.read(filename, top_level=['ancillary'])) == 5)
+        self.assertTrue(len(cf.read(filename, top_level='reference')) == 2)
+        self.assertTrue(len(cf.read(filename, top_level='field')) == 6)
+        self.assertTrue(len(cf.read(filename, top_level=['ancillary', 'auxiliary'])) == 15)
+        self.assertTrue(len(cf.read(filename, top_level=['reference', 'auxiliary'])) == 12)
+        self.assertTrue(len(cf.read(filename, top_level=['field', 'auxiliary'])) == 16)
+        self.assertTrue(len(cf.read(filename, top_level=['field', 'measure', 'auxiliary'])) == 19)
+        self.assertTrue(len(cf.read(filename, top_level='coordinate')) == 16)
+        self.assertTrue(len(cf.read(filename, top_level='all')) == 24)
+        self.assertTrue(len(cf.read(filename, top_level=('field', 'measure', 'coordinate'))) == 24)
     #--- End: def
 
     def test_read_write(self):
